/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { IMenuOption } from '../../menu';
import { BaseComponent, IBaseComponent } from '../../core/base/base-component';
export interface IAppBarHelpButtonComponent extends IBaseComponent {
    options: IMenuOption[];
    icon: string;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-app-bar-help-button': IAppBarHelpButtonComponent;
    }
}
/**
 * @tag forge-app-bar-help-button
 *
 * @description A utility component with predefined icon and descriptions for use in an app bar `end` slot.
 *
 * @property {IMenuOption[]} [options=[]] - The menu options to display when the button is clicked
 * @property {string} [icon=help] - The name of an alternative icon to display.
 *
 * @attribute {string} [icon=help] - The name of an alternative icon to display.
 * @attribute {string} [aria-label] - The aria-label to apply to the button.
 * @attribute {string} [aria-labelledby] - The id of an element to use as the aria-labelledby attribute.
 *
 * @event {CustomEvent<IMenuSelectEventData>} forge-menu-select - Bubbles up the menu select from the internal menu component.
 */
export declare class AppBarHelpButtonComponent extends BaseComponent implements IAppBarHelpButtonComponent {
    static get observedAttributes(): string[];
    private _core;
    constructor();
    initializedCallback(): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    options: IMenuOption[];
    icon: string;
}
