/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { IAppBarSearchInputEventData } from './app-bar-search-constants';
import { BaseComponent, IBaseComponent } from '../../core/base/base-component';
export interface IAppBarSearchComponent extends IBaseComponent {
    disabled: boolean;
    value: string;
    placeholder: string;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-app-bar-search': IAppBarSearchComponent;
    }
    interface HTMLElementEventMap {
        'forge-app-bar-search-input': CustomEvent<IAppBarSearchInputEventData>;
    }
}
/**
 * @tag forge-app-bar-search
 *
 * @slot - The default (unnamed) slot is where child `<input>` elements will be placed.
 * @slot action - Places actions at the end of the input.
 *
 * @attribute {boolean} [disabled=false] - A boolean attribute that, if present, indicates that the input should be disabled.
 * @attribute {string} value - The value of the input.
 * @attribute {string} placeholder - The placeholder text of the input.
 *
 * @property {boolean} [disabled=false] - A boolean property that, if true, indicates that the input should be disabled.
 * @property {string} value - The value of the input.
 * @property {string} placeholder - The placeholder text of the input.
 *
 * @csspart root - The root element
 * @csspart container - The input container element.
 * @csspart icon-container - The icon container element.
 * @csspart icon - The <forge-icon> element.
 * @csspart context - The context container element.
 * @csspart context-divider - The context divider element.
 * @csspart context-button - The context button element.
 * @csspart context-button-text - The context button text element.
 * @csspart context-button-icon - The context button icon element.
 * @csspart global-icon-container - The global icon container element.
 * @csspart global-icon - The global icon <forge-icon> element.
 * @csspart actions-container - The action container element around the slot.
 *
 * @cssproperty --forge-theme-on-primary - Controls the border-color of the container outline, the font-color, and icon color.
 * @cssproperty --forge-theme-on-surface - Controls the font color of the buttons.
 * @cssproperty --forge-theme-text-medium - Controls the placeholder font color.
 * @cssproperty --forge-app-bar-search-theme-background - Controls the background-color of the container.
 * @cssproperty --forge-app-bar-search-theme-background-focused - Controls the focused background-color of the container.
 * @cssproperty --forge-app-bar-search-theme-hover-opacity - Controls the hover opacity of the outline.
 * @cssproperty --forge-app-bar-search-theme-disabled-opacity - Controls the disabled opacity of the component.
 *
 * @event {CustomEvent<IAppBarSearchInputEventData>} forge-app-bar-search-input - Emits when the users executes the search via pressing the Enter key while the `<input>` has focus.
 */
export declare class AppBarSearchComponent extends BaseComponent implements IAppBarSearchComponent {
    static get observedAttributes(): string[];
    private _core;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    value: string;
    disabled: boolean;
    placeholder: string;
}
