/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { PropertyValues, TemplateResult } from 'lit';
import { CUSTOM_ELEMENT_NAME_PROPERTY } from '@tylertech/forge-core';
import { BaseLitElement } from '../core/base/base-lit-element';
export interface IAvatarComponent extends BaseLitElement {
    text: string;
    letterCount: number;
    imageUrl: string;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-avatar': IAvatarComponent;
    }
}
export declare const AVATAR_TAG_NAME: keyof HTMLElementTagNameMap;
/**
 * @tag forge-avatar
 *
 * @summary Avatars represent an entity via text or image.
 *
 * @cssproperty {string} --forge-avatar-background - The background color of the avatar.
 * @cssproperty {number} --forge-avatar-shape - The border radius of the avatar, defaults to 50%.
 * @cssproperty {color} --forge-avatar-color - The text color of the avatar.
 * @cssproperty {number} --forge-avatar-size - The height and width of the avatar.
 * @cssproperty {number} --forge-avatar-transition-duration - The transition duration for animations.
 * @cssproperty {string} --forge-avatar-transition-timing - The transition timing function for animations.
 *
 * @csspart root - The root container element.
 *
 * @slot - The default slot for avatar content if not provided via text/imageUrl.
 *
 * @cssclass forge-avatar - The avatar class _(required)_.
 */
export declare class AvatarComponent extends BaseLitElement implements IAvatarComponent {
    static styles: import("lit").CSSResult;
    /** @deprecated Used for compatibility with legacy Forge @customElement decorator. */
    static [CUSTOM_ELEMENT_NAME_PROPERTY]: keyof HTMLElementTagNameMap;
    /**
     * The text to display in the avatar.
     * @default ''
     * @attribute
     */
    text: string;
    /**
     * Controls the number of letters to display from the text. By default the text is split on spaces and the first character of each word is used.
     * @attribute letter-count
     */
    letterCount: number;
    /**
     * The background image URL to use.
     * @default ''
     * @attribute image-url
     */
    imageUrl: string;
    private _image;
    willUpdate(changedProperties: PropertyValues<this>): void;
    render(): TemplateResult;
    private _tryLoadImage;
}
