/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { PropertyValues, TemplateResult } from 'lit';
import { BadgeTheme } from './badge-constants';
import { CUSTOM_ELEMENT_NAME_PROPERTY } from '@tylertech/forge-core';
import { BaseLitElement } from '../core/base/base-lit-element';
export interface IBadgeComponent extends BaseLitElement {
    dot: boolean;
    theme: BadgeTheme;
    strong: boolean;
    hide: boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-badge': IBadgeComponent;
    }
}
export declare const BADGE_TAG_NAME: keyof HTMLElementTagNameMap;
/**
 * @tag forge-badge
 *
 * @cssproperty --forge-badge-background - The background color.
 * @cssproperty --forge-badge-color - The text color.
 * @cssproperty --forge-badge-shape - The shape radius.
 * @cssproperty --forge-badge-padding-inline - The inline padding.
 * @cssproperty --forge-badge-padding-block - The block padding.
 * @cssproperty --forge-badge-border-width - The border width.
 * @cssproperty --forge-badge-border-color - The border color.
 * @cssproperty --forge-badge-border-style - The border style.
 * @cssproperty --forge-badge-gap - The spacing between the content within the badge.
 *
 * @slot - Default content placed inside the badge.
 * @slot start - Content placed before the default content.
 * @slot end - Content placed after the default content.
 *
 * @state dot - The badge is rendered as a dot.
 * @state strong - The badge has a stronger visual appearance.
 * @state hide - The badge is hidden.
 *
 * @cssclass forge-badge - The badge class _(required)_.
 * @cssclass forge-badge--dot - Renders the badge as a dot.
 * @cssclass forge-badge__icon - Styles a child element as an icon.
 */
export declare class BadgeComponent extends BaseLitElement implements IBadgeComponent {
    #private;
    static styles: import("lit").CSSResult;
    /** @deprecated Used for compatibility with legacy Forge @customElement decorator. */
    static [CUSTOM_ELEMENT_NAME_PROPERTY]: keyof HTMLElementTagNameMap;
    constructor();
    /** Controls whether the badge will be a small dot without any content visible. */
    dot: boolean;
    /** The theme of the badge. */
    theme: BadgeTheme;
    /** Controls whether the badge will have a stronger visual appearance. */
    strong: boolean;
    /** Controls whether the badge is visible. */
    hide: boolean;
    willUpdate(changedProperties: PropertyValues<this>): void;
    render(): TemplateResult;
}
