/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { BaseComponent, IBaseComponent } from '../core/base/base-component';
import { BannerTheme } from './banner-constants';
import { BannerCore } from './banner-core';
export interface IBannerComponent extends IBaseComponent {
    dismissed: boolean;
    persistent: boolean;
    theme: BannerTheme;
    /** @deprecated Use `persistent` instead. */
    canDismiss: boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-banner': IBannerComponent;
    }
    interface HTMLElementEventMap {
        'forge-banner-before-dismiss': CustomEvent<void>;
        'forge-banner-dismissed': CustomEvent<void>;
    }
}
/**
 * @tag forge-banner
 *
 * @summary Banners are used to inform users of important information, such as errors, warnings, or success messages.
 *
 * @property {boolean} [dismissed=false] - Controls the visibility of the banner.
 * @property {boolean} [persistent=false] - Controls the visibility of the built-in dismiss button.
 * @property {BannerTheme} [theme="info"] - The theme of the banner.
 *
 * @attribute {boolean} [dismissed=false] - Controls the visibility of the banner.
 * @attribute {boolean} [persistent=false] - Controls the visibility of the built-in dismiss button.
 * @attribute {BannerTheme} [theme="info"] - The theme of the banner.
 *
 * @event {CustomEvent<void>} forge-banner-before-dismiss - Dispatched before the banner is dismissed. Cancelable to prevent dismissal.
 * @event {CustomEvent<void>} forge-banner-dismissed - Dispatched when the banner is dismissed.
 *
 * @cssproperty --forge-banner-background - The background color of the banner.
 * @cssproperty --forge-banner-color - The text color of the banner.
 * @cssproperty --forge-banner-icon-color - The color of the icon.
 * @cssproperty --forge-banner-gap - The gap between the contents.
 * @cssproperty --forge-banner-padding-inline - The inline padding.
 * @cssproperty --forge-banner-padding-block - The block padding.
 * @cssproperty --forge-banner-transition-duration - The transition duration.
 * @cssproperty --forge-banner-transition-easing - The transition easing function.
 *
 * @slot - The content of the banner.
 * @slot icon - The icon to display.
 * @slot button - The optional button to display.
 *
 * @cssclass forge-banner - The banner class _(required)_.
 */
export declare class BannerComponent extends BaseComponent implements IBannerComponent {
    static get observedAttributes(): string[];
    protected _core: BannerCore;
    constructor();
    connectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    dismissed: boolean;
    persistent: boolean;
    theme: BannerTheme;
    /** @deprecated Use `persistent` instead. */
    get canDismiss(): boolean;
    set canDismiss(value: boolean);
}
