/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { ChipFieldCore } from './chip-field-core';
import { BaseField, IBaseField } from '../field/base/base-field';
export interface IChipFieldComponent extends IBaseField {
    addOnBlur: boolean;
    readonly popoverTargetElement: HTMLElement;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-chip-field': IChipFieldComponent;
    }
    interface HTMLElementEventMap {
        'forge-chip-field-member-added': CustomEvent<string>;
        'forge-chip-field-member-removed': CustomEvent<HTMLElement>;
    }
}
/**
 * @tag forge-chip-field
 *
 * @property {boolean} [addOnBlur=false] - Whether or not to add chip when blur event
 * @property {boolean} popoverTargetElement - The target element for the popover.
 *
 * @attribute {boolean} [add-on-blur=false] - Whether or not to add chip when blur event
 *
 * @event {CustomEvent<IButtonToggleSelectEventData>} forge-button-toggle-select - Dispatches when the user toggles the button.
 *
 * @cssproperty --forge-chip-field-member-spacing - The spacing between chip members.
 * @cssproperty --forge-chip-field-content-spacing - The spacing around chips group.
 */
export declare class ChipFieldComponent extends BaseField<ChipFieldCore> implements IChipFieldComponent {
    static get observedAttributes(): string[];
    protected _core: ChipFieldCore;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    addOnBlur: boolean;
    get popoverTargetElement(): HTMLElement;
    click(): void;
}
