/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { IRGBA, IHSVA } from './color-picker-constants';
/**
 * Calcuates coordinates relative to the provided element based on absolute coordinates.
 * @param absX The x coordinate in screen space.
 * @param absY The y coordinate in screen space.
 * @param element The element to calculate the relative coordinates from.
 */
export declare function relativeCoords(absX: number, absY: number, element: HTMLElement): {
    x: number;
    y: number;
    height: number;
    width: number;
};
export declare function hsvaToRgba(hsva: IHSVA): IRGBA;
export declare function rgbaToHex(rgba: IRGBA): string;
export declare function toHex(x: number): string;
export declare function hexToRgba(hex: string): IRGBA;
export declare function formatRgba(rgba: IRGBA): string;
export declare function formatHex(value: string, allowOpacity: boolean): string;
export declare function rgbaToHsva(rgba: IRGBA): IHSVA;
/**
 * Determines if the provided hex color string is valid.
 * @param value The hex color string.
 */
export declare function isValidHex(value: string): boolean;
/**
 * Determines if the provided RGBA values are valid.
 * @param value The RGBA color values.
 */
export declare function isValidRGBA(value: IRGBA): boolean;
/**
 * Determines if the provided HSVA values are valid.
 * @param value The HSVA color values.
 */
export declare function isValidHSVA(value: IHSVA): boolean;
