/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { AbstractConstructor, MixinBase } from '../../../../constants';
/**
 * The delay in milliseconds before a longpress event is detected.
 */
export declare const LONGPRESS_TRIGGER_DELAY = 500;
export declare abstract class WithLongpressListenerContract {
    /**
     * The delay in milliseconds before a longpress event is detected.
     */
    protected _longpressDelay: number;
    /**
     * Called when a longpress event is detected.
     */
    protected abstract _onLongpress(): void;
    /**
     * Called after a longpress event has been detected, but after the user has released the pointer.
     */
    protected _onLongpressEnd(evt: PointerEvent | TouchEvent): void;
    /**
     * Starts listening for longpress events.
     */
    protected _startLongpressListener(el: HTMLElement): void;
    /**
     * Stops listening for longpress events.
     */
    protected _stopLongpressListener(el: HTMLElement): void;
}
export declare function WithLongpressListener<TBase extends MixinBase<object>>(base?: TBase): AbstractConstructor<WithLongpressListenerContract> & TBase;
