/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { AbstractConstructor, internals, MixinBase } from '../../../constants';
import { IBaseComponent } from '../../base/base-component';
/**
 * A component with attached Element Internals.
 */
export interface IWithElementInternals extends IBaseComponent {
    /**
     * The Element Internals of the component.
     */
    readonly [internals]: ElementInternals;
}
export declare abstract class WithElementInternalsContract {
    readonly [internals]: ElementInternals;
}
/**
 * Mixes in Element Internals functionality into a base component.
 *
 * @param base The base component to mix into.
 * @returns The mixed-in base component.
 */
export declare function WithElementInternals<TBase extends MixinBase>(base: TBase): AbstractConstructor<WithElementInternalsContract> & TBase;
