/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { BaseAdapter, IBaseAdapter } from '../core/base/base-adapter';
import { IDialogComponent } from './dialog';
export interface IDialogAdapter extends IBaseAdapter<IDialogComponent> {
    readonly hostElement: IDialogComponent;
    readonly moveHandleElement: HTMLElement;
    readonly surfaceElement: HTMLElement;
    triggerElement: HTMLElement | null;
    destroy(): void;
    show(): void;
    hide(): Promise<void>;
    addDialogFormSubmitListener(listener: EventListener): void;
    removeDialogFormSubmitListener(listener: EventListener): void;
    addBackdropDismissListener(listener: EventListener): void;
    removeBackdropDismissListener(listener: EventListener): void;
    tryAutofocus(): void;
    tryLocateTriggerElement(id: string | null): void;
    addTriggerInteractionListener(listener: EventListener): void;
    removeTriggerInteractionListener(listener: EventListener): void;
    hideBackdrop(): void;
    showBackdrop(): void;
    addSurfaceClass(className: string): void;
    removeSurfaceClass(className: string): void;
    addFullscreenListener(breakpoint: number, listener: (value: boolean) => void): void;
    removeFullscreenListener(listener: (value: boolean) => void): void;
    setAccessibleLabel(label: string): void;
    setAccessibleDescription(description: string): void;
}
export declare class DialogAdapter extends BaseAdapter<IDialogComponent> implements IDialogAdapter {
    private _dialogElement;
    private _surfaceElement;
    private _backdropElement;
    private _moveHandleElement;
    private _fullscreenMediaQuery;
    private _accessibleLabelElement;
    private _accessibleDescriptionElement;
    triggerElement: HTMLElement | null;
    get moveHandleElement(): HTMLElement;
    get surfaceElement(): HTMLElement;
    constructor(component: IDialogComponent);
    destroy(): void;
    show(): void;
    private _hideBackdrops;
    private _showBackdropMostRecent;
    hide(): Promise<void>;
    addDialogFormSubmitListener(listener: EventListener): void;
    removeDialogFormSubmitListener(listener: EventListener): void;
    addBackdropDismissListener(listener: EventListener): void;
    removeBackdropDismissListener(listener: EventListener): void;
    tryAutofocus(): void;
    tryLocateTriggerElement(id: string | null): void;
    addTriggerInteractionListener(listener: EventListener): void;
    removeTriggerInteractionListener(listener: EventListener): void;
    hideBackdrop(): void;
    showBackdrop(): void;
    addSurfaceClass(className: string): void;
    removeSurfaceClass(className: string): void;
    addFullscreenListener(breakpoint: number, listener: (value: boolean) => void): void;
    removeFullscreenListener(listener: (value: boolean) => void): void;
    setAccessibleLabel(label: string): void;
    setAccessibleDescription(description: string): void;
    private _forceClose;
}
