/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { IDialogAdapter } from './dialog-adapter';
import { DialogAnimationType, DialogCloseReason, DialogMode, DialogPlacement, DialogPositionStrategy, DialogPreset, DialogSizeStrategy, DialogType } from './dialog-constants';
export interface IDialogCore {
    open: boolean;
    mode: DialogMode;
    type: DialogType;
    animationType: DialogAnimationType;
    preset: DialogPreset;
    persistent: boolean;
    fullscreen: boolean;
    fullscreenThreshold: number;
    trigger: string;
    triggerElement: HTMLElement | null;
    positionStrategy: DialogPositionStrategy;
    sizeStrategy: DialogSizeStrategy;
    placement: DialogPlacement;
    moveable: boolean;
    label: string;
    description: string;
    hideBackdrop(): void;
    showBackdrop(): void;
    dispatchBeforeCloseEvent(reason: DialogCloseReason): boolean;
}
export declare class DialogCore implements IDialogCore {
    _adapter: IDialogAdapter;
    private _open;
    private _mode;
    private _type;
    private _animationType;
    private _preset;
    private _persistent;
    private _fullscreen;
    private _fullscreenThreshold;
    private _originalFullscreenValue;
    private _trigger;
    private _moveable;
    private _label;
    private _description;
    private _sizeStrategy;
    private _placement;
    private _positionStrategy;
    private _moveController;
    private _escapeDismissListener;
    private _backdropDismissListener;
    private _dialogFormSubmitListener;
    private _triggerClickListener;
    private _fullscreenListener;
    constructor(_adapter: IDialogAdapter);
    initialize(): void;
    destroy(): void;
    dispatchBeforeCloseEvent(reason: DialogCloseReason): boolean;
    hideBackdrop(): void;
    showBackdrop(): void;
    private _show;
    private _hide;
    private _release;
    private _tryResetFullscreenValue;
    private _applyOpen;
    private _onEscapeDismiss;
    private _onBackdropDismiss;
    private _onDialogFormSubmit;
    private _onFullscreenChange;
    private _tryClose;
    private _onTriggerClick;
    private _initializeMoveController;
    private _destroyMoveController;
    private _applyMoveable;
    get open(): boolean;
    set open(value: boolean);
    get mode(): DialogMode;
    set mode(value: DialogMode);
    get type(): DialogType;
    set type(value: DialogType);
    get animationType(): DialogAnimationType;
    set animationType(value: DialogAnimationType);
    get preset(): DialogPreset;
    set preset(value: DialogPreset);
    get persistent(): boolean;
    set persistent(value: boolean);
    get fullscreen(): boolean;
    set fullscreen(value: boolean);
    get fullscreenThreshold(): number;
    set fullscreenThreshold(value: number);
    get trigger(): string;
    set trigger(value: string);
    get triggerElement(): HTMLElement | null;
    set triggerElement(element: HTMLElement | null);
    get moveable(): boolean;
    set moveable(value: boolean);
    get label(): string;
    set label(value: string);
    get description(): string;
    set description(value: string);
    get positionStrategy(): DialogPositionStrategy;
    set positionStrategy(value: DialogPositionStrategy);
    get sizeStrategy(): DialogSizeStrategy;
    set sizeStrategy(value: DialogSizeStrategy);
    get placement(): DialogPlacement;
    set placement(value: DialogPlacement);
}
