/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { BaseComponent, IBaseComponent } from '../core/base/base-component';
export interface IDividerComponent extends IBaseComponent {
    vertical: boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-divider': IDividerComponent;
    }
}
/**
 * @tag forge-divider
 *
 * @summary Divider is used to separate elements.
 *
 * @property {boolean} [vertical=false] - Controls if the divider is displayed vertically or horizontally.
 *
 * @attribute {boolean} [vertical=false] - Controls if the divider is displayed vertically or horizontally.
 *
 * @cssproperty --forge-divider-color - The color of the divider.
 * @cssproperty --forge-divider-width - The width of the divider.
 * @cssproperty --forge-divider-border-style - The border-style (dashed, solid) of the divider.
 * @cssproperty --forge-divider-margin - The margin of divider.
 *
 * @csspart root - The root container element.
 *
 * @cssclass forge-divider - The divider class.
 */
export declare class DividerComponent extends BaseComponent implements IDividerComponent {
    static get observedAttributes(): string[];
    constructor();
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    get vertical(): boolean;
    set vertical(value: boolean);
}
