/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { addClass } from '@tylertech/forge-core';
import { ICON_CONSTANTS } from '../icon';
import { ICON_CLASS_NAME } from '../constants';
import { BaseComponentDelegate } from '../core/delegates/base-component-delegate';
import { ICON_BUTTON_CONSTANTS } from './icon-button-constants';
export class IconButtonComponentDelegate extends BaseComponentDelegate {
    constructor(config) {
        super(config);
    }
    _build() {
        const component = document.createElement(ICON_BUTTON_CONSTANTS.elementName);
        if (this._config.options?.tooltip) {
            const tooltip = document.createElement('forge-tooltip');
            tooltip.textContent = this._config.options.tooltip;
            if (this._config.options.tooltipPosition) {
                tooltip.placement = this._config.options.tooltipPosition;
            }
            component.appendChild(tooltip);
        }
        return component;
    }
    get iconElement() {
        return this._iconElement;
    }
    get disabled() {
        return !!this._element.disabled;
    }
    set disabled(value) {
        this._element.disabled = value;
    }
    _configure() {
        this._configureIcon();
    }
    _configureIcon() {
        if (!this._config.options?.iconName) {
            return;
        }
        const type = this._config.options?.iconType || 'component';
        switch (type) {
            case 'font':
                const classes = Array.isArray(this._config.options.iconClass) ? this._config.options.iconClass : [ICON_CLASS_NAME];
                addClass(classes, this._element);
                this._element.textContent = this._config.options.iconName;
                break;
            case 'component':
                this._iconElement = document.createElement(ICON_CONSTANTS.elementName);
                this._iconElement.name = this._config.options.iconName;
                if (this._config.options.iconExternal !== undefined) {
                    this._iconElement.external = !!this._config.options.iconExternal;
                }
                if (this._config.options.iconExternalType) {
                    this._iconElement.externalType = this._config.options.iconExternalType;
                }
                if (this._config.options.iconClass) {
                    addClass(this._config.options.iconClass, this._iconElement);
                }
                this._element.appendChild(this._iconElement);
                break;
        }
    }
    onClick(listener) {
        this._element.addEventListener('click', listener);
    }
    onFocus(listener) {
        this._element.addEventListener('focus', evt => listener(evt));
    }
    onBlur(listener) {
        this._element.addEventListener('blur', evt => listener(evt));
    }
}
