/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { BaseComponent, IBaseComponent } from '../core/base/base-component';
import { InlineMessageTheme } from './inline-message-constants';
export interface IInlineMessageComponent extends IBaseComponent {
    theme: InlineMessageTheme;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-inline-message': IInlineMessageComponent;
    }
}
/**
 * @tag forge-inline-message
 *
 * @summary Inline messages are used to provide feedback to the user about a specific action or state.
 *
 * @property {InlineMessageTheme} [theme="info"] - The theme to apply.
 *
 * @attribute {InlineMessageTheme} [theme="info"] - The theme to apply.
 *
 * @cssproperty --forge-inline-message-background - The background color.
 * @cssproperty --forge-inline-message-color - The text color.
 * @cssproperty --forge-inline-message-shape - The shape (border) radius.
 * @cssproperty --forge-inline-message-padding - The padding around the content.
 * @cssproperty --forge-inline-message-padding-inline - The inline padding around the content.
 * @cssproperty --forge-inline-message-padding-block - The block padding around the content.
 * @cssproperty --forge-inline-message-border-width - The border width.
 * @cssproperty --forge-inline-message-border-style - The border style. Defaults to `none`.
 * @cssproperty --forge-inline-message-border-color - The border color.
 * @cssproperty --forge-inline-message-gap - The gap/space between the content elements.
 * @cssproperty --forge-inline-message-icon-gap - The gap/space between the icon and the content.
 * @cssproperty --forge-inline-message-content-gap - The gap/space between the title and the message.
 * @cssproperty --forge-inline-message-icon-color - The icon color.
 *
 * @csspart root - The root layout element.
 * @csspart container - The container element for the title and message content.
 *
 * @cssclass forge-inline-message - The inline message container element.
 * @cssclass forge-inline-message__title - The title element.
 * @cssclass forge-inline-message__icon - The icon element.
 *
 * @slot - The message text.
 * @slot title - The title of the inline message.
 * @slot icon - The icon to display.
 */
export declare class InlineMessageComponent extends BaseComponent implements IInlineMessageComponent {
    constructor();
    get theme(): InlineMessageTheme;
    set theme(value: InlineMessageTheme);
}
