/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { TemplateResult } from 'lit';
import { CUSTOM_ELEMENT_NAME_PROPERTY } from '@tylertech/forge-core';
import { BaseLitElement } from '../../core/base/base-lit-element';
export declare const KEY_ITEM_TAG_NAME: keyof HTMLElementTagNameMap;
/**
 * @tag forge-key-item
 *
 * @summary Key items label a chart or data visualization.
 *
 * @slot - The default slot for the label.
 * @slot icon - The icon to display.
 * @slot value - The value to display.
 *
 * @cssproperty --forge-key-item-icon-color - The color of the icon.
 * @cssproperty --forge-key-item-label-color - The color of the label.
 * @cssproperty --forge-key-item-value-color - The color of the value.
 * @cssproperty --forge-key-item-gap - The spacing between the icon and label.
 * @cssproperty --forge-key-item-icon-size - The size of the icon.
 *
 * @csspart root - The root element.
 * @csspart icon - The icon element.
 * @csspart label - The label element.
 * @csspart value - The value element.
 */
export declare class KeyItemComponent extends BaseLitElement {
    static styles: import("lit").CSSResult;
    /** @deprecated Used for compatibility with legacy Forge @customElement decorator. */
    static [CUSTOM_ELEMENT_NAME_PROPERTY]: keyof HTMLElementTagNameMap;
    /**
     * Whether the label and value dislay on one line.
     * @default false
     * @attribute
     */
    inline: boolean;
    private _hasValue;
    private _valueNodes;
    private _internals;
    constructor();
    connectedCallback(): void;
    render(): TemplateResult;
    private _handleSlotChange;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-key-item': KeyItemComponent;
    }
}
