/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { BaseComponent, IBaseComponent } from '../core';
import { SkipLinkTheme } from './skip-link-constants';
export interface ISkipLinkComponent extends IBaseComponent {
    target: string;
    theme: SkipLinkTheme;
    muted: boolean;
    persistent: boolean;
    inline: boolean;
    skipUrlChange: boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-skip-link': ISkipLinkComponent;
    }
}
/**
 * @tag forge-skip-link
 *
 * @summary The Forge Skip Link component is used to provide a way for users to skip repetitive content and navigate directly to a section of the page.
 *
 * @cssproperty --forge-skip-link-background - The background color of the skip link.
 * @cssproperty --forge-skip-link-color - The text color of the skip link.
 * @cssproperty --forge-skip-link-shape - The border radius of the skip link.
 * @cssproperty --forge-skip-link-inset - The skip link's inset from the edge of the viewport.
 * @cssproperty --forge-skip-link-z-index - The z-index of the skip link.
 * @cssproperty --forge-skip-link-elevation - The box shadow of the skip link.
 * @cssproperty --forge-skip-link-padding-block - The interior padding of the skip link along the block axis.
 * @cssproperty --forge-skip-link-padding-inline - The interior padding of the skip link along the inline axis.
 * @cssproperty --forge-skip-link-focus-indicator-color - The color of the focus indicator.
 * @cssproperty --forge-skip-link-transition-duration - The duration of the skip link's animations.
 * @cssproperty --forge-skip-link-transition-timing-function - The timing function of the skip link's animations.
 *
 * @csspart anchor - The root anchor element.
 * @csspart focus-indicator - The focus indicator element.
 * @csspart state-layer - The state layer element.
 *
 * @slot - The default/unnamed slot for link text.
 *
 * @dependency forge-focus-indicator
 * @dependency forge-state-layer
 */
export declare class SkipLinkComponent extends BaseComponent implements ISkipLinkComponent {
    static get observedAttributes(): string[];
    private _target;
    private _theme;
    private _muted;
    private _persistent;
    private _inline;
    private _skipUrlChange;
    private _anchorElement;
    private _clickListener;
    constructor();
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    /**
     * The IDREF of the element to which the skip link should navigate.
     * @default ''
     * @attribute
     */
    get target(): string;
    set target(value: string);
    /**
     * The theme applied to the skip link.
     * @default 'default'
     * @attribute
     */
    get theme(): SkipLinkTheme;
    set theme(value: SkipLinkTheme);
    /**
     * Whether or not the skip link uses a muted color scheme.
     * @default false
     * @attribute
     */
    get muted(): boolean;
    set muted(value: boolean);
    /**
     * Whether or not the skip link should remain visible when not focused.
     * @default false
     * @attribute
     */
    get persistent(): boolean;
    set persistent(value: boolean);
    /**
     * Whether or not the skip link renders within its container.
     * @default false
     * @attribute
     */
    get inline(): boolean;
    set inline(value: boolean);
    /**
     * Sets the skip link to skip browser navigation and scroll to the target element.
     * @default false
     * @attribute skip-url-change
     */
    get skipUrlChange(): boolean;
    set skipUrlChange(value: boolean);
    private _handleClick;
}
