/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { ButtonTheme } from '../button';
import { BaseComponent, IBaseComponent } from '../core/base/base-component';
import { SplitButtonVariant } from './split-button-constants';
export interface ISplitButtonComponent extends IBaseComponent {
    variant: SplitButtonVariant;
    theme: ButtonTheme;
    disabled: boolean;
    dense: boolean;
    pill: boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-split-button': ISplitButtonComponent;
    }
}
/**
 * @tag forge-split-button
 *
 * @summary Split buttons are used for splitting an action into two parts.
 *
 * @dependency forge-button
 *
 * @property {SplitButtonVariant} [variant="text"] - The variant of the buttons. Valid values are `text`, `outlined`, `tonal`, `filled`, and `raised`.
 * @property {ButtonTheme} [theme="primary"] - The theme of the buttons. Valid values are `primary`, `secondary`, `tertiary`, `success`, `error`, `warning`, `info`.
 * @property {boolean} [disabled=false] - Whether or not the buttons are disabled.
 * @property {boolean} [dense=false] - Whether or not the buttons are dense.
 * @property {boolean} [pill=false] - Whether or not the buttons are pill-shaped.
 *
 * @attribute {SplitButtonVariant} [variant="text"] - The variant of the buttons. Valid values are `text`, `outlined`, `tonal`, `filled`, and `raised`.
 * @attribute {ButtonTheme} [theme="primary"] - The theme of the buttons. Valid values are `primary`, `secondary`, `tertiary`, `success`, `error`, `warning`, `info`.
 * @attribute {boolean} [disabled=false] - Whether or not the buttons are disabled.
 * @attribute {boolean} [dense=false] - Whether or not the buttons are dense.
 * @attribute {boolean} [pill=false] - Whether or not the buttons are pill-shaped.
 *
 * @cssproperty --forge-split-button-min-width - The minimum width of the slotted buttons.
 * @cssproperty --forge-split-button-gap - The gap between the slotted buttons.
 * @cssproperty --forge-split-button-focus-indicator-offset - The offset of the focus indicator around the buttons.
 * @cssproperty --forge-split-button-focus-indicator-divider-offset - The offset of the focus indicator divider when using outlined buttons.
 *
 * @slot - This is a default/unnamed slot.
 */
export declare class SplitButtonComponent extends BaseComponent implements ISplitButtonComponent {
    static get observedAttributes(): string[];
    private readonly _core;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    variant: SplitButtonVariant;
    theme: ButtonTheme;
    disabled: boolean;
    dense: boolean;
    pill: boolean;
}
