/**
 * @license
 * Copyright Tyler Technologies, Inc. 
 * License: Apache-2.0
 */
import { ViewSwitcherAnimation, ViewSwitcherAnimationType } from './view-switcher-constants';
import { BaseComponent, IBaseComponent } from '../core/base/base-component';
export interface IViewSwitcherComponent extends IBaseComponent {
    index: number;
    animationType: `${ViewSwitcherAnimationType}` | ViewSwitcherAnimation;
    next(): void;
    previous(): void;
    goToStart(): void;
    goToEnd(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'forge-view-switcher': IViewSwitcherComponent;
    }
}
/**
 * @tag forge-view-switcher
 *
 * @dependency forge-view
 */
export declare class ViewSwitcherComponent extends BaseComponent implements IViewSwitcherComponent {
    static get observedAttributes(): string[];
    private _core;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    /**
     * Gets/sets the currently visible view index.
     * @default 0
     * @attribute
     */
    index: number;
    /**
     * Gets/sets the animation type.
     * @default "none"
     * @attribute animation-type
     */
    animationType: `${ViewSwitcherAnimationType}` | ViewSwitcherAnimation;
    /** Transitions to the next view. */
    next(): void;
    /** Transitions to the previous view. */
    previous(): void;
    /** Transitions to the first view. */
    goToStart(): void;
    /** Transitions to the last view. */
    goToEnd(): void;
}
